@@ -43,8 +43,8 @@ Usage:
 Without arguments, it will parse defaults from 
 PANIC.DefaultArgs property of Tango Database
 
---scope will constrain the devices accessed by the application, cannot
-be changed on runtime.
+--scope will constrain the devices accessed by the application (panic api),
+    cannot be changed on runtime (e.g. --scope="*/di/*").
 
 --default will setup a default regular expression to be applied when 
 the search field is empty. It will be overriden by any expression entered
@@ -111,6 +111,7 @@ class QAlarmList(QAlarmManager,PARENT_CLASS):
         self.tools = {} #Widgets dictionary
         
         self.scope = options.get('scope','*') #filters or '*'
+        exported = options.get('exported','')
         self.default_regEx = options.get('default',filters or '*')
         self.regEx = self.default_regEx
         self.NO_ICON = Qt.QIcon()
@@ -124,16 +125,21 @@ class QAlarmList(QAlarmManager,PARENT_CLASS):
             #self._ui.regExLine.setText(str(self.regEx))
         
         print('AlarmGUI(%s, %s)'%(api,self.scope))
-        self.api = api or panic.AlarmAPI(self.scope)
-        print('AlarmGUI(%s): api done, %d devs, %d alarms' % 
-              (self.scope, len(self.api.devices), len(self.api.alarms)))
+        self.api = api or panic.AlarmAPI(None)
+        self.api.load(self.scope, exported=exported)
+        print('AlarmGUI(%s,%s): api done, %d devs, %d alarms' % 
+              (self.scope, exported, len(self.api.devices), 
+               len(self.api.alarms)))
 
         self.init_ui(parent,mainwindow) #init_mw is called here
         
         # @TODO: api-based views are not multi-host
-        self.view = panic.view.AlarmView(api=self.api,scope=self.scope,
-                refresh = self.REFRESH_TIME/1e3,events=False,verbose=1) 
-        trace('AlarmGUI(): view done')
+        self.view = panic.view.AlarmView(api=self.api,
+                    scope=self.scope,
+                    refresh = self.REFRESH_TIME/1e3,
+                    events=False,
+                    verbose=1) 
+        trace('AlarmGUI(): view created')
         
         self.snaps = None
 
@@ -155,7 +161,7 @@ class QAlarmList(QAlarmManager,PARENT_CLASS):
         self.init_timers()
         self.init_filters()        
         
-        trace('AlarmGUI(): signals done')
+        trace('AlarmGUI(): signals connected')
         ## connection of ui signals is delayed until first onRefresh()
         
         self.updateStatusLabel()
